@@ -4,10 +4,12 @@ use strict;
 use warnings;
 use v5.10;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 # ABSTRACT: A factory class for building all the other classes in C<JIRA::REST::Class>.
 
+# here is our list of every class this factory knows how to make
+#
 JIRA::REST::Class::Factory->add_factory_type(
     factory      => 'JIRA::REST::Class::Factory',
     issue        => 'JIRA::REST::Class::Issue',
@@ -36,18 +38,39 @@ JIRA::REST::Class::Factory->add_factory_type(
 use Carp;
 use DateTime::Format::Strptime;
 
+#pod =internal_method B<init>
+#pod
+#pod Initialize the factory object.  Just copies all the elements in the hashref that were passed in to the object itself.
+#pod
+#pod =cut
 
-sub jira { shift->{jira} }
+sub init {
+    my $self = shift;
+    my $args = shift;
+    my @keys = keys %$args;
+    @{$self}{@keys} = @{$args}{@keys};
+    return $self;
+}
 
+#pod =internal_method B<make_object>
+#pod
+#pod A tweaked version of the object creator from C<Class::Factory::Enhanced> that calls C<init()> with a copy of the factory.
+#pod
+#pod =cut
 
 sub make_object {
     my ($self, $object_type, @args) = @_;
     my $class = $self->get_factory_class($object_type);
     my $obj = $class->new(@args);
-    $obj->init($self);
+    $obj->init($self); # make sure we pass the factory into init()
     return $obj;
 }
 
+#pod =internal_method B<make_date>
+#pod
+#pod Make it easy to get C<DateTime> objects from the factory.
+#pod
+#pod =cut
 
 sub make_date {
     my ($self, $date) = @_;
@@ -56,6 +79,11 @@ sub make_date {
     return $parser->parse_datetime($date);
 }
 
+#pod =internal_method B<factory_error>
+#pod
+#pod Throws errors from the factory with stack traces
+#pod
+#pod =cut
 
 sub factory_error {
     my $class = shift;
@@ -73,23 +101,25 @@ __END__
 
 =encoding UTF-8
 
+=for :stopwords Packy Anderson Alexey Melezhik
+
 =head1 NAME
 
 JIRA::REST::Class::Factory - A factory class for building all the other classes in C<JIRA::REST::Class>.
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 INTERNAL METHODS
 
-=head2 B<jira>
+=head2 B<init>
 
-Accessor for the C<JIRA::REST::Class> object used to talk to the server.
+Initialize the factory object.  Just copies all the elements in the hashref that were passed in to the object itself.
 
 =head2 B<make_object>
 
-A tweaked version of the object creator from C<Class::Factory::Enhanced>.
+A tweaked version of the object creator from C<Class::Factory::Enhanced> that calls C<init()> with a copy of the factory.
 
 =head2 B<make_date>
 
