@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use v5.10;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 # ABSTRACT: A helper class for C<JIRA::REST::Class> that represents an individual JIRA issue as an object.
 
@@ -64,7 +64,8 @@ sub init {
     my $self = shift;
     $self->SUPER::init(@_);
 
-    $self->{url} = $self->jira->strip_protocol_and_host($self->self);
+    my $jira = $self->jira;
+    $self->{url} = $jira->strip_protocol_and_host($self->self);
 
     # make user objects
     foreach my $field ( @USERS ) {
@@ -76,17 +77,17 @@ sub init {
         $self->{$field} = $self->make_date( $self->fields->{$field} );
     }
 
-    $self->populate_list_field('components',     'projectcomp',  'components');
+    $self->populate_list_field(  'components',   'projectcomp',  'components');
     $self->populate_scalar_field('project',      'project',      'project');
     $self->populate_scalar_field('issuetype',    'issuetype',    'issuetype');
     $self->populate_scalar_field('status',       'status',       'status');
     $self->populate_scalar_field('timetracking', 'timetracking', 'timetracking');
-    $self->populate_list_field('versions',       'projectvers',  'versions');
+    $self->populate_list_field(  'versions',     'projectvers',  'versions');
 
     unless (defined &is_bug) {
         # if we haven't defined booleans to determine whether or not this
         # issue is a particular type, define those methods now
-        foreach my $type ( $self->jira->issue_types ) {
+        foreach my $type ( $jira->issue_types ) {
             (my $subname = lc 'is_'.$type->name) =~ s/\s+|\-/_/g;
             $self->make_subroutine($subname, sub {
                 shift->fields->{issuetype}->{id} == $type->id
@@ -134,6 +135,11 @@ __PACKAGE__->mk_lazy_ro_accessor('timetracking', sub {
     $self->make_object('timetracking');
 });
 
+#pod =method B<make_object>
+#pod
+#pod A pass-through method that calls C<JIRA::REST::Class::Factory::make_object()>, but adds a weakened link to this issue in the object as well.
+#pod
+#pod =cut
 
 sub make_object {
     my $self = shift;
@@ -159,6 +165,61 @@ sub make_object {
 
 ###########################################################################
 
+#pod =method B<add_attachments>
+#pod
+#pod Accepts a list of filenames to be added to the issue as attachments.
+#pod
+#pod =cut
+
+sub add_attachments {
+    my $self = shift;
+
+    foreach my $file ( @_ ) {
+        croak "unable to find attachment $file"
+            unless -f $file;
+
+        $self->JIRA_REST->attach_files($self->key, $file);
+    }
+}
+
+#pod =method B<add_attachment>
+#pod
+#pod Accepts a single filename to be added to the issue as an attachment.
+#pod
+#pod =cut
+
+sub add_attachment {
+    my $self = shift;
+    my $file = shift;
+
+    croak "unable to find attachment $file"
+        unless -f $file;
+
+    $self->JIRA_REST->attach_files($self->key, $file);
+}
+
+#pod =method B<add_data_attachment>
+#pod
+#pod Accepts a fake filename and a scalar representing the contents of a file and adds it to the issue as an attachment.
+#pod
+#pod =cut
+
+sub add_data_attachment {
+    my $self = shift;
+    my $name = shift;
+    my $data = shift;
+    my $url  = q{/} . join q{/}, 'issue', $self->key, 'attachments';
+
+    $self->jira->data_upload({
+        url => $url, name => $name, data => $data
+    });
+}
+
+#pod =method B<add_comment>
+#pod
+#pod Adds whatever is passed in as a comment on the issue.
+#pod
+#pod =cut
 
 sub add_comment {
     my $self = shift;
@@ -166,6 +227,11 @@ sub add_comment {
     $self->post("/comment", { body => $text });
 }
 
+#pod =method B<add_label>
+#pod
+#pod Adds whatever is passed in as a label for the issue.
+#pod
+#pod =cut
 
 sub add_label {
     my $self  = shift;
@@ -173,6 +239,11 @@ sub add_label {
     $self->update( labels => [ { add => $label } ] );
 }
 
+#pod =method B<remove_label>
+#pod
+#pod Removes whatever is passed in from the labels for the issue.
+#pod
+#pod =cut
 
 sub remove_label {
     my $self  = shift;
@@ -180,6 +251,26 @@ sub remove_label {
     $self->update( labels => [ { remove => $label } ] );
 }
 
+#pod =method B<has_label>
+#pod
+#pod Returns true if the issue has the specified label.
+#pod
+#pod =cut
+
+sub has_label {
+    my $self  = shift;
+    my $label = shift;
+    foreach my $has ( $self->labels ) {
+        return 1 if $label eq $has;
+    }
+    return 0;
+}
+
+#pod =method B<add_component>
+#pod
+#pod Adds whatever is passed in as a component for the issue.
+#pod
+#pod =cut
 
 sub add_component {
     my $self = shift;
@@ -187,6 +278,11 @@ sub add_component {
     $self->update( components => [ { add => { name => $comp } } ] );
 }
 
+#pod =method B<remove_component>
+#pod
+#pod Removes whatever is passed in from the components for the issue.
+#pod
+#pod =cut
 
 sub remove_component {
     my $self = shift;
@@ -194,6 +290,11 @@ sub remove_component {
     $self->update( components => [ { remove => { name => $comp } } ] );
 }
 
+#pod =method B<set_assignee>
+#pod
+#pod Sets the assignee for the issue to be the user passed in.  Can either be a string representing the name or a C<JIRA::REST::Class::User> object.
+#pod
+#pod =cut
 
 sub set_assignee {
     my $self = shift;
@@ -201,6 +302,11 @@ sub set_assignee {
     $self->put_field(assignee => { name => $name });
 }
 
+#pod =method B<set_reporter>
+#pod
+#pod Sets the reporter for the issue to be the user passed in.  Can either be a string representing the name or a C<JIRA::REST::Class::User> object.
+#pod
+#pod =cut
 
 sub set_reporter {
     my $self = shift;
@@ -208,6 +314,11 @@ sub set_reporter {
     $self->put_field(reporter => { name => $name });
 }
 
+#pod =method B<add_issue_link>
+#pod
+#pod Adds a link from this issue to another one.  Accepts the link type (either a string representing the name or a C<JIRA::REST::Class::Issue::LinkType>), the issue to be linked to, and (optionally) the direction of the link (inward/outward).  If the direction cannot be determined from the name of the link type, the default direction is 'inward';
+#pod
+#pod =cut
 
 sub add_issue_link {
     my ($self, $type, $key, $dir) = @_;
@@ -223,6 +334,13 @@ sub add_issue_link {
     $self->update( issuelinks => $links );
 }
 
+#pod =method B<add_subtask>
+#pod
+#pod Adds a subtask to the current issue.  Accepts a hashref with named parameters 'summary' and 'description'.  If the parameter 'issuetype' is specified, then a subtask of the specified type is created.  If no issuetype is specified, then the project is queried for valid subtask types, and, if there is only one, that type is used.  If the project has more than one valid subtask type, an issuetype MUST be specified.
+#pod
+#pod The remaining named parameters are passed to the create issue call as fields.
+#pod
+#pod =cut
 
 sub add_subtask {
     my($summary, $desc, $fields, $issuetype);
@@ -335,6 +453,11 @@ sub add_subtask {
 
 ###########################################################################
 
+#pod =method B<update>
+#pod
+#pod Puts an update to JIRA.  Accepts a hash of fields => values to be put.
+#pod
+#pod =cut
 
 sub update {
     my $self = shift;
@@ -349,6 +472,11 @@ sub update {
     });
 }
 
+#pod =method B<put_field>
+#pod
+#pod Puts a value to a field.  Accepts the field name and the value as parameters.
+#pod
+#pod =cut
 
 sub put_field {
     my $self  = shift;
@@ -359,6 +487,11 @@ sub put_field {
     });
 }
 
+#pod =method B<reload>
+#pod
+#pod Reload the issue from the JIRA server.
+#pod
+#pod =cut
 
 sub reload {
     my $self = shift;
@@ -368,6 +501,11 @@ sub reload {
 
 ###########################################################################
 
+#pod =internal_method B<get>
+#pod
+#pod Wrapper around C<JIRA::REST>'s GET method that defaults to this issue's URL. Allows for extra parameters to be specified.
+#pod
+#pod =cut
 
 sub get {
     my $self  = shift;
@@ -375,6 +513,11 @@ sub get {
     $self->jira->get($self->url . $extra, @_);
 }
 
+#pod =internal_method B<delete>
+#pod
+#pod Wrapper around C<JIRA::REST::Class>' DELETE method that defaults to this issue's URL. Allows for extra parameters to be specified.
+#pod
+#pod =cut
 
 sub delete {
     my $self  = shift;
@@ -382,12 +525,22 @@ sub delete {
     $self->jira->delete($self->url . $extra, @_);
 }
 
+#pod =internal_method B<put>
+#pod
+#pod Wrapper around C<JIRA::REST::Class>' PUT method that defaults to this issue's URL. Allows for extra parameters to be specified.
+#pod
+#pod =cut
 
 sub put {
     my $self = shift;
     $self->jira->put($self->url, @_);
 }
 
+#pod =internal_method B<post>
+#pod
+#pod Wrapper around C<JIRA::REST::Class>' POST method that defaults to this issue's URL. Allows for extra parameters to be specified.
+#pod
+#pod =cut
 
 sub post {
     my $self = shift;
@@ -395,12 +548,17 @@ sub post {
     $self->jira->post($self->url . $extra, @_);
 }
 
+#pod =method B<sprints>
+#pod
+#pod Generates a list of C<JIRA::REST::Class::Sprint> objects from the fields for an issue.  Uses the field_name() method on the C<JIRA::REST::Class> object to determine the name of the custom sprint field.
+#pod
+#pod =cut
 
 __PACKAGE__->mk_lazy_ro_accessor('sprints', sub {
     my $self = shift;
 
     # in my configuration, 'Sprint' is a custom field
-    my $sprint_field = $self->jira->field_name('Sprint');
+    my $sprint_field = $self->project->field_name('Sprint');
 
     my @sprints;
     foreach my $sprint ( @{ $self->fields->{$sprint_field} } ) {
@@ -409,6 +567,11 @@ __PACKAGE__->mk_lazy_ro_accessor('sprints', sub {
     return \@sprints;
 });
 
+#pod =method B<children>
+#pod
+#pod Returns a list of issue objects that are children of the issue. Requires the ScriptRunner plugin.
+#pod
+#pod =cut
 
 sub children {
     my $self = shift;
@@ -424,6 +587,11 @@ sub children {
 
 ###########################################################################
 
+#pod =method B<start_progress>
+#pod
+#pod Moves the status of the issue to 'In Progress', regardless of what the current status is.
+#pod
+#pod =cut
 
 sub start_progress {
     my $self     = shift;
@@ -440,6 +608,11 @@ sub start_progress {
     }, $callback);
 }
 
+#pod =method B<start_qa>
+#pod
+#pod Moves the status of the issue to 'In QA', regardless of what the current status is.
+#pod
+#pod =cut
 
 sub start_qa {
     my $self     = shift;
@@ -456,6 +629,11 @@ sub start_qa {
     }, $callback);
 }
 
+#pod =method B<resolve>
+#pod
+#pod Moves the status of the issue to 'Resolved', regardless of what the current status is.
+#pod
+#pod =cut
 
 sub resolve {
     my $self     = shift;
@@ -472,6 +650,11 @@ sub resolve {
     }, $callback);
 }
 
+#pod =method B<open>
+#pod
+#pod Moves the status of the issue to 'Open', regardless of what the current status is.
+#pod
+#pod =cut
 
 sub open {
     my $self     = shift;
@@ -488,6 +671,11 @@ sub open {
     }, $callback);
 }
 
+#pod =method B<close>
+#pod
+#pod Moves the status of the issue to 'Closed', regardless of what the current status is.
+#pod
+#pod =cut
 
 sub close {
     my $self     = shift;
@@ -513,13 +701,24 @@ __END__
 
 =encoding UTF-8
 
+=for :stopwords Packy Anderson Alexey Melezhik Atlassian ScriptRunner TODO
+aggregateprogress aggregatetimeestimate aggregatetimeoriginalestimate
+assigneeType avatar avatarUrls completeDate displayName duedate
+emailAddress endDate fieldtype fixVersions fromString genericized iconUrl
+isAssigneeTypeValid issueTypes issuelinks issuetype jira jql lastViewed
+maxResults originalEstimate originalEstimateSeconds parentkey projectId
+rapidViewId remainingEstimate remainingEstimateSeconds resolutiondate
+sprintlist startDate subtaskIssueTypes timeSpent timeSpentSeconds
+timeestimate timeoriginalestimate timespent timetracking toString
+updateAuthor worklog workratio
+
 =head1 NAME
 
 JIRA::REST::Class::Issue - A helper class for C<JIRA::REST::Class> that represents an individual JIRA issue as an object.
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 READ-ONLY ACCESSORS
 
@@ -731,6 +930,18 @@ Returns the JIRA REST API's URL for this issue in a form used by C<JIRA::REST::C
 
 A pass-through method that calls C<JIRA::REST::Class::Factory::make_object()>, but adds a weakened link to this issue in the object as well.
 
+=head2 B<add_attachments>
+
+Accepts a list of filenames to be added to the issue as attachments.
+
+=head2 B<add_attachment>
+
+Accepts a single filename to be added to the issue as an attachment.
+
+=head2 B<add_data_attachment>
+
+Accepts a fake filename and a scalar representing the contents of a file and adds it to the issue as an attachment.
+
 =head2 B<add_comment>
 
 Adds whatever is passed in as a comment on the issue.
@@ -743,6 +954,10 @@ Adds whatever is passed in as a label for the issue.
 
 Removes whatever is passed in from the labels for the issue.
 
+=head2 B<has_label>
+
+Returns true if the issue has the specified label.
+
 =head2 B<add_component>
 
 Adds whatever is passed in as a component for the issue.
