@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use v5.10;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 # ABSTRACT: A helper class for C<JIRA::REST::Class> that represents the time tracking for a JIRA issue as an object.
 
@@ -18,6 +18,11 @@ sub init {
     $self->{data} = $data->{fields}->{timetracking};
 }
 
+#pod =accessor B<originalEstimate>
+#pod
+#pod Returns the original estimate as a number of seconds in numeric context, and as a w/d/h/m/s string in a string context.
+#pod
+#pod =cut
 
 sub originalEstimate {
     my $self = shift;
@@ -27,6 +32,11 @@ sub originalEstimate {
     ;
 }
 
+#pod =accessor B<remainingEstimate>
+#pod
+#pod Returns the remaining estimate as a number of seconds in numeric context, and as a w/d/h/m/s string in a string context.
+#pod
+#pod =cut
 
 sub remainingEstimate {
     my $self = shift;
@@ -36,6 +46,11 @@ sub remainingEstimate {
     ;
 }
 
+#pod =accessor B<timeSpent>
+#pod
+#pod Returns the time spent as a number of seconds in numeric context, and as a w/d/h/m/s string in a string context.
+#pod
+#pod =cut
 
 sub timeSpent {
     my $self = shift;
@@ -45,6 +60,11 @@ sub timeSpent {
     ;
 }
 
+#pod =method B<set_originalEstimate>
+#pod
+#pod Sets the original estimate to the amount of time given.  Accepts any time format that JIRA uses.
+#pod
+#pod =cut
 
 sub set_originalEstimate {
     my $self = shift;
@@ -52,6 +72,11 @@ sub set_originalEstimate {
     $self->update( { originalEstimate => $est } );
 }
 
+#pod =method B<set_remainingEstimate>
+#pod
+#pod Sets the remaining estimate to the amount of time given.  Accepts any time format that JIRA uses.
+#pod
+#pod =cut
 
 sub set_remainingEstimate {
     my $self = shift;
@@ -59,6 +84,11 @@ sub set_remainingEstimate {
     $self->update( { remainingEstimate => $est } );
 }
 
+#pod =method B<update>
+#pod
+#pod Accepts a hashref of timetracking fields to update. The acceptable fields are determined by JIRA, but I think they're originalEstimate and remainingEstimate.
+#pod
+#pod =cut
 
 sub update {
     my $self   = shift;
@@ -87,13 +117,24 @@ __END__
 
 =encoding UTF-8
 
+=for :stopwords Packy Anderson Alexey Melezhik Atlassian ScriptRunner TODO
+aggregateprogress aggregatetimeestimate aggregatetimeoriginalestimate
+assigneeType avatar avatarUrls completeDate displayName duedate
+emailAddress endDate fieldtype fixVersions fromString genericized iconUrl
+isAssigneeTypeValid issueTypes issuelinks issuetype jira jql lastViewed
+maxResults originalEstimate originalEstimateSeconds parentkey projectId
+rapidViewId remainingEstimate remainingEstimateSeconds resolutiondate
+sprintlist startDate subtaskIssueTypes timeSpent timeSpentSeconds
+timeestimate timeoriginalestimate timespent timetracking toString
+updateAuthor worklog workratio
+
 =head1 NAME
 
 JIRA::REST::Class::Issue::TimeTracking - A helper class for C<JIRA::REST::Class> that represents the time tracking for a JIRA issue as an object.
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 READ-ONLY ACCESSORS
 
