@@ -6,7 +6,7 @@ use v5.10;
 
 use Carp;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 # ABSTRACT: A helper class for C<JIRA::REST::Class> that represents the state transitions a JIRA issue can go through.
 
@@ -24,6 +24,11 @@ sub init {
 }
 
 
+#pod =internal_method B<find_transition_named>
+#pod
+#pod Returns the transition object for the named transition provided.
+#pod
+#pod =cut
 
 sub find_transition_named {
     my $self = shift;
@@ -34,35 +39,91 @@ sub find_transition_named {
         return $transition;
     }
 
-    die "Unable to find transition '$name'\n"
-      . "\ntransitions: " . $self->shallow_dump($self->transitions)
-      . "\nissue: " . $self->shallow_dump($self->issue);
+    die sprintf(
+        "Unable to find transition '%s'\n".
+        "issue status: %s\n".
+        "transitions:  %s\n",
+        $name, $self->issue->status->name,
+        $self->dump([ $self->transitions ]),
+    );
 }
 
+#pod =method B<block>
+#pod
+#pod Blocks the issue.
+#pod
+#pod =cut
 
 sub block { shift->find_transition_named("Block Issue")->go(@_) }
 
+#pod =method B<close>
+#pod
+#pod Closes the issue.
+#pod
+#pod =cut
 
 sub close { shift->find_transition_named("Close Issue")->go(@_) }
 
+#pod =method B<verify>
+#pod
+#pod Verifies the issue.
+#pod
+#pod =cut
 
 sub verify { shift->find_transition_named("Verify Issue")->go(@_) }
 
+#pod =method B<resolve>
+#pod
+#pod Resolves the issue.
+#pod
+#pod =cut
 
 sub resolve { shift->find_transition_named("Resolve Issue")->go(@_) }
 
+#pod =method B<reopen>
+#pod
+#pod Reopens the issue.
+#pod
+#pod =cut
 
 sub reopen { shift->find_transition_named("Reopen Issue")->go(@_) }
 
+#pod =method B<start_progress>
+#pod
+#pod Starts progress on the issue.
+#pod
+#pod =cut
 
 sub start_progress { shift->find_transition_named("Start Progress")->go(@_) }
 
+#pod =method B<stop_progress>
+#pod
+#pod Stops progress on the issue.
+#pod
+#pod =cut
 
 sub stop_progress { shift->find_transition_named("Stop Progress")->go(@_) }
 
+#pod =method B<start_qa>
+#pod
+#pod Starts QA on the issue.
+#pod
+#pod =cut
 
 sub start_qa { shift->find_transition_named("Start QA")->go(@_) }
 
+#pod =method B<transition_walk>
+#pod
+#pod This method takes three unnamed parameters:
+#pod   + The name of the end target issue status
+#pod   + A hashref mapping possible current states to intermediate states
+#pod     that will progress the issue towards the end target issue status
+#pod   + A callback subroutine reference that will be called after each
+#pod     transition with the name of the current issue state and the name
+#pod     of the state it is transitioning to (defaults to an empty subroutine
+#pod     reference).
+#pod
+#pod =cut
 
 my %state_to_transition = (
     'Open'        => 'Stop Progress',
@@ -90,8 +151,8 @@ sub transition_walk {
             unless ( exists $state_to_transition{$to} ) {
                 die "Unknown target state '$to'!\n";
             }
-            my $trans = $self->find_transition_named( $state_to_transition{$to} )
-              or die "No transition for target state '$to'!\n";
+            my $trans =
+                $self->find_transition_named( $state_to_transition{$to} );
             $callback->($name, $to);
             $trans->go;
         }
@@ -99,9 +160,7 @@ sub transition_walk {
             die "Don't know how to transition from '$name' to '$target'!\n";
         }
 
-        # refresh the data for this issue
-        $self->issue->reload;
-        $self->init($self->factory);
+        # get the new status name
         $name = $self->issue->status->name;
     }
 
@@ -120,13 +179,15 @@ __END__
 
 =encoding UTF-8
 
+=for :stopwords Packy Anderson Alexey Melezhik
+
 =head1 NAME
 
 JIRA::REST::Class::Issue::Transitions - A helper class for C<JIRA::REST::Class> that represents the state transitions a JIRA issue can go through.
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 METHODS
 
