@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use v5.10;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 # ABSTRACT: A helper class for C<JIRA::REST::Class> that represents the state transitions a JIRA issue can go through.
 
@@ -19,12 +19,24 @@ sub init {
     $self->{to} = $self->make_object('status', { data => $self->data->{to} });
 }
 
+#pod =method B<go>
+#pod
+#pod Perform the transition represented by this object on the issue.
+#pod
+#pod =cut
 
 sub go {
     my $self = shift;
     $self->issue->post("/transitions", {
         transition => { id => $self->id }, @_
     });
+
+    # reload the issue itself, since it's going to have a new status,
+    # which will mean new transitions
+    $self->issue->reload;
+
+    # reload these new transitions
+    $self->issue->transitions->init($self->factory);
 }
 
 1;
@@ -35,13 +47,15 @@ __END__
 
 =encoding UTF-8
 
+=for :stopwords Packy Anderson Alexey Melezhik
+
 =head1 NAME
 
 JIRA::REST::Class::Issue::Transitions::Transition - A helper class for C<JIRA::REST::Class> that represents the state transitions a JIRA issue can go through.
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 METHODS
 
