@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use v5.10;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Readonly;
 
@@ -39,13 +39,24 @@ __END__
 
 =encoding UTF-8
 
+=for :stopwords Packy Anderson Alexey Melezhik Atlassian ScriptRunner TODO
+aggregateprogress aggregatetimeestimate aggregatetimeoriginalestimate
+assigneeType avatar avatarUrls completeDate displayName duedate
+emailAddress endDate fieldtype fixVersions fromString genericized iconUrl
+isAssigneeTypeValid issueTypes issuelinks issuetype jira jql lastViewed
+maxResults originalEstimate originalEstimateSeconds parentkey projectId
+rapidViewId remainingEstimate remainingEstimateSeconds resolutiondate
+sprintlist startDate subtaskIssueTypes timeSpent timeSpentSeconds
+timeestimate timeoriginalestimate timespent timetracking toString
+updateAuthor worklog workratio
+
 =head1 NAME
 
 JIRA::REST::Class::Issue::Worklog::Item - A helper class for C<JIRA::REST::Class> that represents an individual worklog item for a JIRA issue as an object.
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 READ-ONLY ACCESSORS
 
