@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use v5.10;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 # ABSTRACT: A helper class for C<JIRA::REST::Class> that represents a JIRA project as an object.
 
@@ -76,6 +76,67 @@ sub _do_lazy_load {
     }
 }
 
+#pod =method B<assigneeType>
+#pod
+#pod This method returns the assignee type of the project.
+#pod
+#pod =method B<avatarUrls>
+#pod
+#pod A hashref of the different sizes available for the project's avatar.
+#pod
+#pod =method B<components>
+#pod
+#pod A list of the components for the project.
+#pod
+#pod =method B<description>
+#pod
+#pod Returns the description of the project.
+#pod
+#pod =method B<expand>
+#pod
+#pod Heck if I know what this field does.
+#pod
+#pod =method B<id>
+#pod
+#pod Returns the id of the project.
+#pod
+#pod =method B<issueTypes>
+#pod
+#pod A list of valid issue types for the project.
+#pod
+#pod =method B<subtaskIssueTypes>
+#pod
+#pod Taking a page from the old SOAP interface, this method returns a list of all issue types whose subtask field is true.
+#pod
+#pod =method B<key>
+#pod
+#pod Returns the key of the project.
+#pod
+#pod =method B<lead>
+#pod
+#pod Returns the project lead as a C<JIRA::REST::Class::User> object.
+#pod
+#pod =method B<name>
+#pod
+#pod Returns the name of the project.
+#pod
+#pod =method B<category>
+#pod
+#pod Returns a hashref of the category of the project.
+#pod
+#pod =method B<self>
+#pod
+#pod Returns the JIRA REST API URL of the project.
+#pod
+#pod =method B<versions>
+#pod
+#pod Returns a list of the versions of the project.
+#pod
+#pod =method B<metadata>
+#pod
+#pod Returns the metadata associated with this project.
+#pod
+#pod =cut
 
 sub metadata {
     my $self = shift;
@@ -86,27 +147,57 @@ sub metadata {
             maxResults => 1,
         });
         my $issuekey = $first_issue->key;
-        $self->{metadata} = $self->get("/issue/$issuekey/editmeta");
+        $self->{metadata} = $self->jira->get("/issue/$issuekey/editmeta");
     }
 
     return $self->{metadata};
 }
 
+#pod =method B<allowed_components>
+#pod
+#pod Returns a list of the allowed values for the 'components' field in the project.
+#pod
+#pod =cut
 
 sub allowed_components   { shift->allowed_field_values('components', @_);  }
 
+#pod =method B<allowed_versions>
+#pod
+#pod Returns a list of the allowed values for the 'versions' field in the project.
+#pod
+#pod =cut
 
 sub allowed_versions     { shift->allowed_field_values('versions', @_); }
 
+#pod =method B<allowed_fix_versions>
+#pod
+#pod Returns a list of the allowed values for the 'fixVersions' field in the project.
+#pod
+#pod =cut
 
 sub allowed_fix_versions { shift->allowed_field_values('fixVersions', @_); }
 
+#pod =method B<allowed_issue_types>
+#pod
+#pod Returns a list of the allowed values for the 'issuetype' field in the project.
+#pod
+#pod =cut
 
 sub allowed_issue_types  { shift->allowed_field_values('issuetype', @_);   }
 
+#pod =method B<allowed_priorities>
+#pod
+#pod Returns a list of the allowed values for the 'priority' field in the project.
+#pod
+#pod =cut
 
 sub allowed_priorities   { shift->allowed_field_values('priority', @_);    }
 
+#pod =internal_method B<allowed_field_values> FIELD_NAME
+#pod
+#pod Returns a list of allowable values for the specified field in the project.
+#pod
+#pod =cut
 
 sub allowed_field_values {
     my $self = shift;
@@ -119,6 +210,11 @@ sub allowed_field_values {
     return @list;
 }
 
+#pod =internal_method B<field_metadata_exists> FIELD_NAME
+#pod
+#pod Boolean indicating whether there is metadata for a given field in the project.
+#pod
+#pod =cut
 
 sub field_metadata_exists {
     my $self = shift;
@@ -130,6 +226,11 @@ sub field_metadata_exists {
 }
 
 
+#pod =internal_method B<field_metadata> FIELD_NAME
+#pod
+#pod Looks for metadata under either a field's key or name in the project.
+#pod
+#pod =cut
 
 sub field_metadata {
     my $self = shift;
@@ -145,6 +246,11 @@ sub field_metadata {
     return;
 }
 
+#pod =internal_method B<field_name> FIELD_KEY
+#pod
+#pod Looks up field names in the project metadata in the project.
+#pod
+#pod =cut
 
 sub field_name {
     my $self = shift;
@@ -169,13 +275,24 @@ __END__
 
 =encoding UTF-8
 
+=for :stopwords Packy Anderson Alexey Melezhik Atlassian ScriptRunner TODO
+aggregateprogress aggregatetimeestimate aggregatetimeoriginalestimate
+assigneeType avatar avatarUrls completeDate displayName duedate
+emailAddress endDate fieldtype fixVersions fromString genericized iconUrl
+isAssigneeTypeValid issueTypes issuelinks issuetype jira jql lastViewed
+maxResults originalEstimate originalEstimateSeconds parentkey projectId
+rapidViewId remainingEstimate remainingEstimateSeconds resolutiondate
+sprintlist startDate subtaskIssueTypes timeSpent timeSpentSeconds
+timeestimate timeoriginalestimate timespent timetracking toString
+updateAuthor worklog workratio
+
 =head1 NAME
 
 JIRA::REST::Class::Project - A helper class for C<JIRA::REST::Class> that represents a JIRA project as an object.
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 METHODS
 
