@@ -4,19 +4,29 @@ use strict;
 use warnings;
 use v5.10;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 # ABSTRACT: A helper class for C<JIRA::REST::Class> that represents a JIRA query as an object.  Attempts to return an array of all results from the query.
 
 
+#pod =method B<issue_count>
+#pod
+#pod A count of the number of issues matched by the query.
+#pod
+#pod =cut
 
 sub issue_count { shift->data->{total} }
 
+#pod =method B<issues>
+#pod
+#pod Returns a list of C<JIRA::REST::Class::Issue> objects matching the query.
+#pod
+#pod =cut
 
 sub issues {
     my $self = shift;
     my @issues = map {
-        $self->factory->make_object('issue', { data => $_ });
+        $self->make_object('issue', { data => $_ });
     } @{ $self->data->{issues} };
     return @issues;
 }
@@ -29,13 +39,15 @@ __END__
 
 =encoding UTF-8
 
+=for :stopwords Packy Anderson Alexey Melezhik
+
 =head1 NAME
 
 JIRA::REST::Class::Query - A helper class for C<JIRA::REST::Class> that represents a JIRA query as an object.  Attempts to return an array of all results from the query.
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 METHODS
 
