@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use v5.10;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 # ABSTRACT: A helper class for C<JIRA::REST::Class> that represents the sprint of a JIRA issue as an object.
 
@@ -30,17 +30,49 @@ sub init {
 
 1;
 
+#pod =accessor B<id>
+#pod
+#pod =accessor B<rapidViewId>
+#pod
+#pod =accessor B<state>
+#pod
+#pod =accessor B<name>
+#pod
+#pod =accessor B<startDate>
+#pod
+#pod =accessor B<endDate>
+#pod
+#pod =accessor B<completeDate>
+#pod
+#pod =accessor B<sequence>
+#pod
+#pod =for stopwords Atlassian ScriptRunner TODO aggregateprogress aggregatetimeestimate aggregatetimeoriginalestimate assigneeType avatar avatarUrls completeDate displayName duedate emailAddress endDate fieldtype fixVersions fromString genericized iconUrl isAssigneeTypeValid issueTypes issuelinks issuetype jira jql lastViewed maxResults originalEstimate originalEstimateSeconds parentkey projectId rapidViewId remainingEstimate remainingEstimateSeconds resolutiondate sprintlist startDate subtaskIssueTypes timeSpent timeSpentSeconds timeestimate timeoriginalestimate timespent timetracking toString updateAuthor worklog workratio
+#pod
+#pod
+#pod =cut
+
 =pod
 
 =encoding UTF-8
 
+=for :stopwords Packy Anderson Alexey Melezhik Atlassian ScriptRunner TODO
+aggregateprogress aggregatetimeestimate aggregatetimeoriginalestimate
+assigneeType avatar avatarUrls completeDate displayName duedate
+emailAddress endDate fieldtype fixVersions fromString genericized iconUrl
+isAssigneeTypeValid issueTypes issuelinks issuetype jira jql lastViewed
+maxResults originalEstimate originalEstimateSeconds parentkey projectId
+rapidViewId remainingEstimate remainingEstimateSeconds resolutiondate
+sprintlist startDate subtaskIssueTypes timeSpent timeSpentSeconds
+timeestimate timeoriginalestimate timespent timetracking toString
+updateAuthor worklog workratio
+
 =head1 NAME
 
 JIRA::REST::Class::Sprint - A helper class for C<JIRA::REST::Class> that represents the sprint of a JIRA issue as an object.
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 READ-ONLY ACCESSORS
 
